Routemaster
===========

State machines as a service.

Routemaster is designed to enable the creation of complex, but clearly defined,
state machines used by multiple separate services.

For more information see https://github.com/thread/routemaster.
